<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:tei="http://www.tei-c.org/ns/1.0" exclude-result-prefixes="tei" version="2.0">
	<!-- <xsl:import href="ecartae.xsl"/> -->

	<xsl:output encoding="UTF-8" indent="no" method="xml" omit-xml-declaration="yes"/>
	<xsl:variable name="cellRendition">
		<xsl:copy-of select="//tei:tagsDecl"/>
	</xsl:variable>
	<xsl:template match="/">
		<xsl:text disable-output-escaping="yes">&lt;!DOCTYPE html&gt;</xsl:text>

		<html>
			<head>
				<meta charset="UTF-8"/>
				<title>
					<xsl:value-of select="//tei:titleStmt/tei:title"/>
				</title>
				<link href="ressources/tei.css" rel="stylesheet" type="text/css"/>
				<link rel="stylesheet" type="text/css" media="screen" href="http://cdnjs.cloudflare.com/ajax/libs/fancybox/1.3.4/jquery.fancybox-1.3.4.css"/>
				<script type="text/javascript" src="http://code.jquery.com/jquery-1.10.0.min.js"/>
				<script src="ressources/tei.js" charset="utf-8" type="text/javascript"/>
				<script>
      			jQuery(document).ready(function(){
					layoutMarginNotes();
				});
      	</script>
				<script src="ressources/tei.js" charset="utf-8" type="text/javascript"/>
				<script>
      			jQuery(document).ready(function(){
					scrollToID(id);
				});
      	</script>
			</head>

			<body>
				<article>
					<xsl:apply-templates/>
					<div class="notes">
						<hr class="notes"/>
						<xsl:call-template name="apparat_notes"/>
						<xsl:call-template name="bas_de_page"/>
					</div>
				</article>

				<footer>
				</footer>
				<script type="text/javascript" src="http://code.jquery.com/jquery-1.11.0.min.js"/>
				<script type="text/javascript" src="http://code.jquery.com/jquery-migrate-1.2.1.min.js"/>
				<script type="text/javascript" src="http://cdnjs.cloudflare.com/ajax/libs/fancybox/1.3.4/jquery.fancybox-1.3.4.pack.min.js"/>
				<script type="text/javascript">
    $(function($){
        var addToAll = true;
        var gallery = true;
        var titlePosition = 'inside';
        $(addToAll ? 'img' : 'img.fancybox').each(function(){
            var $this = $(this);
            var title = $this.attr('title');
            var src = $this.attr('data-big') || $this.attr('src');
            var a = $('<a href="#" class="fancybox"/>').attr('href', src).attr('title', title);
            $this.wrap(a);
        });
        if (gallery)
            $('a.fancybox').attr('rel', 'fancyboxgallery');
        $('a.fancybox').fancybox({
            titlePosition: titlePosition
        });
    });
    $.noConflict();
			</script>
			</body>
		</html>
	</xsl:template>

	<xsl:template match="tei:teiHeader | tei:front"/>

	<!-- ###### niveaux de titres ###### -->
	<xsl:template match="tei:head[@type='general']">
				<h1 class="titre_general">
					<xsl:apply-templates/>
				</h1>
	</xsl:template>

	<xsl:template match="tei:div[@type='section1']/tei:head">
		<h2 class="sous_titre"><xsl:apply-templates/></h2>
	</xsl:template>

	<!-- ###### div/section ###### -->
	<xsl:template match="tei:div[@type]">
		<section>
			<xsl:attribute name="class">
				<xsl:value-of select="@type"/>
			</xsl:attribute>
			<xsl:apply-templates/>
		</section>
	</xsl:template>
	<xsl:template match="tei:p">
		<p>
			<xsl:apply-templates/>
		</p>
	</xsl:template>
	<!-- ###### citations ###### -->
	<xsl:template match="tei:quote">
		<blockquote>
			<xsl:apply-templates/>
		</blockquote>
	</xsl:template>

	<!-- ###### apparat et notes en pop-up ###### -->

<xsl:template match="tei:app">
		 <span class="app">
			 <xsl:apply-templates select="./tei:lem"/>
		 </span>
		 <xsl:variable name="numeroNoteApp">
			 <xsl:number count="//tei:app[not(@type)] | //tei:note[@type='apparat']" level="any" format="a"/>
		 </xsl:variable>
		 <span id="appelNote{$numeroNoteApp}" class="noteApp infobulle note-appel {@type}">
			 <button class="togglerInfobulle apparat">
				 <sup><xsl:text>(</xsl:text>
 				<xsl:value-of select="$numeroNoteApp"/>
 				<xsl:text>)</xsl:text></sup>
     	</button>
			<span class="conteneurInfobulle">
				<span class="infobulleTitle"><xsl:text>Apparat critique</xsl:text></span>
				<br/>
				<xsl:for-each select="descendant::tei:rdg">
					<xsl:text> </xsl:text>
					<xsl:value-of select="."/>
					<xsl:if test="not(text())">
						<em>om.</em>
					</xsl:if>
					<em>
						<xsl:text> </xsl:text>
						<xsl:value-of select="translate(@wit,'#','')"/>
					</em>
				</xsl:for-each>
				<xsl:text>. </xsl:text>
			</span>
		</span>
	 </xsl:template>


	 	<!-- Template pour voir les notes qui n'ont pas d'xml:id : on ne demande pas à la XSL de numéroter les notes de a à z, mais d'afficher entre parenthèses l'xml:id -->
	 <!-- <xsl:template match="tei:app">
			<span class="app">
				<xsl:apply-templates select="./tei:lem"/>
			</span>
			<span id="appelNote{@xml:id}" class="noteApp infobulle note-appel {@type}">
				<button class="togglerInfobulle apparat">
					<sup><xsl:text>(</xsl:text>
					 <xsl:value-of select="@xml:id"/>
					 <xsl:text>)</xsl:text></sup>
				 </button>
			 <span class="conteneurInfobulle">
				 <span class="infobulleTitle"><xsl:text>Apparat critique</xsl:text></span>
				 <br/>
				 <xsl:for-each select="descendant::tei:rdg">
					 <xsl:text> </xsl:text>
					 <xsl:value-of select="."/>
					 <xsl:if test="not(text())">
						 <em>om.</em>
					 </xsl:if>
					 <em>
						 <xsl:text> </xsl:text>
						 <xsl:value-of select="translate(@wit,'#','')"/>
					 </em>
				 </xsl:for-each>
				 <xsl:text>. </xsl:text>
			 </span>
		 </span>
		</xsl:template> -->

	 <xsl:template match="//tei:lem">
		 <span class='lem'>
				 <xsl:apply-templates/>
		 </span>
	 </xsl:template>

	 <xsl:template match="tei:rdg"/>

	 <xsl:template match="tei:witDetail">
			<xsl:variable name="numNotewitDetail">
				<xsl:number count="//tei:witDetail" level="any" format="*1"/>
			</xsl:variable>
			<span id="appelNote{$numNotewitDetail}" class="noteSci infobulle note-appel {@type}">
				<button class="togglerInfobulle witdetail">
 				 	<sup><xsl:number count="//tei:witDetail" level="any" format="*1"/></sup>
				</button>
				<span class="conteneurInfobulle">
 					<span class="infobulleTitle"><xsl:text>witDetail</xsl:text></span>
 					<br/>
 					<xsl:for-each select=".">
 						<xsl:value-of select="."/>
 					</xsl:for-each>
 					<xsl:text>. </xsl:text>
 				</span>
			</span>
		</xsl:template>

	 <!-- <xsl:template match="tei:note[@type='philologique'] | tei:note[@type='sources'] | tei:note[@type='commentaire']| tei:note[@type='apparat']"> -->
		 <xsl:template match="tei:note[@type]">
		 <xsl:for-each select=".">
		 <xsl:choose>
			 <xsl:when test="@type='philologique'">
				 <xsl:variable name="numNotePhil">
					 <xsl:number count="//tei:note[@type='philologique']" level="any" format="a'"/>
				 </xsl:variable>
				 <span id="appelNote{$numNotePhil}" class="noteApp infobulle note-appel {@type}">
					 <button class="togglerInfobulle philologie">
            <sup><xsl:value-of select="$numNotePhil"/></sup>
          </button>
          <span class="conteneurInfobulle">
            <span class="infobulleTitle"><xsl:text>Notes philologiques</xsl:text></span>
              <br/>
              <!-- <xsl:for-each select="."> -->
                <xsl:apply-templates/>
              <!-- </xsl:for-each> -->
              <xsl:text>. </xsl:text>
            </span>
        </span>
			 </xsl:when>
			 <xsl:when test="@type='identification'">
				 <xsl:variable name="numNoteIdent">
					 <xsl:number count="//tei:note[@type='identification']" level="any" format="a'"/>
				 </xsl:variable>
				 <span id="appelNote{$numNoteIdent}" class="noteApp infobulle note-appel {@type}">
					 <button class="togglerInfobulle identification">
            <sup><xsl:value-of select="$numNoteIdent"/></sup>
          </button>
          <span class="conteneurInfobulle">
            <span class="infobulleTitle"><xsl:text>Notes d'identification</xsl:text></span>
              <br/>
              <!-- <xsl:for-each select="."> -->
                <xsl:apply-templates/>
              <!-- </xsl:for-each> -->
              <xsl:text>. </xsl:text>
            </span>
        </span>
			 </xsl:when>
			 <xsl:when test="@type='sources'">
				 <xsl:variable name="numNoteSources">
					 <xsl:number count="//tei:note[@type='sources']" level="any" format="α"/>
				 </xsl:variable>
				<span id="appelNote{$numNoteSources}" class="noteApp infobulle note-appel {@type}">
					<button class="togglerInfobulle sources">
					 <sup><xsl:number count="//tei:note[@type='sources']" level="any" format="α"/></sup>
				 </button>
				 <span class="conteneurInfobulle">
					 <span class="infobulleTitle"><xsl:text>Notes de sources</xsl:text></span>
						 <br/>
						 <!-- <xsl:for-each select="."> -->
							 <xsl:apply-templates/>
						 <!-- </xsl:for-each> -->
						 <xsl:text>. </xsl:text>
					 </span>
			 </span>
			 </xsl:when>
			 <xsl:when test="@type='commentaire'">
				 <xsl:variable name="numNoteComm">
					 <xsl:number count="//tei:note[@type='commentaire']" level="any" format="1"/>
				 </xsl:variable>
				<span id="appelNote{$numNoteComm}" class="noteApp infobulle note-appel {@type}">
					<button class="togglerInfobulle commentaire">
					 <sup><xsl:number count="//tei:note[@type='commentaire']" level="any" format="1"/></sup>
				 </button>
				 <span class="conteneurInfobulle">
					 <span class="infobulleTitle"><xsl:text>Notes de commentaire</xsl:text></span>
						 <br/>
						 <!-- <xsl:for-each select="."> -->
							 <xsl:apply-templates/>
						 <!-- </xsl:for-each> -->
						 <xsl:text>. </xsl:text>
					 </span>
			 </span>
			 </xsl:when>
			 <xsl:when test="@type='travail'">
				 <xsl:variable name="numNoteTravail">
					 <xsl:number count="//tei:note[@type='travail']" level="any" format="1"/>
				 </xsl:variable>
				<span id="appelNote{$numNoteTravail}" class="noteApp infobulle note-appel {@type}">
					<button class="togglerInfobulle travail">
					 <sup>[<xsl:number count="//tei:note[@type='travail']" level="any" format="1"/>]</sup>
				 </button>
				 <span class="conteneurInfobulle">
					 <span class="infobulleTitle"><xsl:text>Notes de travail</xsl:text></span>
						 <br/>
						 <!-- <xsl:for-each select="."> -->
							 <xsl:apply-templates/>
						 <!-- </xsl:for-each> -->
						 <xsl:text>. </xsl:text>
					 </span>
			 </span>
			 </xsl:when>
			 <xsl:when test="@type='apparat'">
				 <span id="appelNote{@xml:id}" class="noteApp infobulle note-appel {@type}">
					 <button class="togglerInfobulle">
            <sup>(<xsl:value-of select="@xml:id"/>)</sup>
          </button>
          <span class="conteneurInfobulle">
            <span class="infobulleTitle"><xsl:text>Notes apparat</xsl:text></span>
              <br/>
              <!-- <xsl:for-each select="."> -->
                <xsl:apply-templates />
              <!-- </xsl:for-each> -->
              <xsl:text>. </xsl:text>
            </span>
        </span>
			 </xsl:when>
			 <xsl:otherwise>
			 	<span id="appelNote{@xml:id}" class="noteApp infobulle note-appel {@type}">
					 <button class="togglerInfobulle">
            <sup>(<xsl:value-of select="@type"/>)</sup>
          </button>
          <span class="conteneurInfobulle">
            <span class="infobulleTitle">
							<xsl:text>Notes </xsl:text>
							<xsl:value-of select="@type"/>
						</span>
              <br/>
              
                <xsl:apply-templates />
              
              <xsl:text>. </xsl:text>
            </span>
        </span>
			 </xsl:otherwise>
			 <!-- <xsl:otherwise/> -->
		 </xsl:choose>
		 </xsl:for-each>
	 </xsl:template>

	 <xsl:template match="tei:sic[@xml:id]">
		 <span class="sic">
			 <xsl:apply-templates/>
		 </span>
		<span id="appelNote{@xml:id}" class="noteApp infobulle note-appel {@type}">
				 <button class="togglerInfobulle">
					<sup>(<xsl:value-of select="@xml:id"/>)</sup>
				</button>
				<span class="conteneurInfobulle">
					<span class="infobulleTitle"><xsl:text>Notes de commentaire</xsl:text></span>
						<br/>
						<xsl:for-each select=".">
							<xsl:apply-templates/>
						</xsl:for-each>
						<xsl:text>. </xsl:text>
					</span>
			</span>
	 </xsl:template>

	<xsl:template match="tei:choice">
		<xsl:apply-templates/>
	</xsl:template>

	<xsl:template match="tei:choice/tei:sic">
		<span class="sic">
			<xsl:apply-templates/>
		</span>
		<span id="appelNote{@xml:id}" class="noteApp infobulle note-appel {@type}">
				 <button class="togglerInfobulle">
					<sup>(<xsl:value-of select="parent::tei:choice/@xml:id"/>)</sup>
				</button>
				<span class="conteneurInfobulle">
					<span class="infobulleTitle"><xsl:text>Notes de commentaire</xsl:text></span>
						<br/>
						<xsl:for-each select=".">
							<xsl:apply-templates/>
						</xsl:for-each>
						<xsl:text>. </xsl:text>
					</span>
			</span>
	</xsl:template>

	<xsl:template match="//tei:span[contains(@class,'varLong')]">
		<span>
			<xsl:attribute name="class">
				<xsl:value-of select="@class"/>
			</xsl:attribute>
			<xsl:apply-templates/>
		</span>
	</xsl:template>

	<!-- ###### bas de page ###### -->

	<!-- ###### apparat ###### -->
	<xsl:template name="apparat_notes">
	<xsl:if test="//tei:rdg | //tei:sic | //tei:app | //tei:choice | //tei:note[@type='apparat']">
						<xsl:choose>
							<xsl:when test="//tei:app">
								<div class="note_app">
									<h4 class="apparat">Apparat</h4>
									<p>
										<xsl:call-template name="apparat_bdp"/>
									</p>
								</div>
							</xsl:when>
							<xsl:otherwise>
								<div class="note_app">
									<h4>Apparat</h4>
									<p>
										<xsl:for-each select="//tei:note[@type='apparat']">
											<xsl:variable name="numeroNoteapp">
												<xsl:number count="//tei:note[@type='apparat']" level="any" format="a"/>
											</xsl:variable>
											<span class="note_bas_de_page">
												<span class="num_note" onclick="scrollToID('appelNote{$numeroNoteapp}')" style="cursor:pointer">
													<xsl:value-of select="$numeroNoteapp"/>
													<xsl:text>. </xsl:text>
												</span>
												<span class="note_bdp">
													<xsl:apply-templates/>
												</span>
											</span>
											<xsl:text> | </xsl:text>
										</xsl:for-each>
									</p>
								</div>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:if>
	</xsl:template>

	<xsl:template name="apparat_bdp">
		<xsl:for-each select="//tei:app[not(@type)] | //tei:note[@type='apparat']">
			<xsl:variable name="appelnoteBdp">
				<xsl:text>(</xsl:text>
					<xsl:number count="//tei:app[not(@type)] | //tei:note[@type='apparat']" level="any" format="a"/>
				<xsl:text>)</xsl:text>
			</xsl:variable>
				<span class="app" id="rdgBdp{@xml:id}">
					<xsl:variable name="numNoteApp">
						<xsl:number count="//tei:app[not(@type)] | //tei:note[@type='apparat']" level="any" format="a"/>
					</xsl:variable>
					<span class="numApp" onclick="scrollToID('appelNote{$numNoteApp}')" style="cursor:pointer">
						<xsl:text>(</xsl:text>
						<xsl:value-of select="$numNoteApp"/>
						<xsl:text>) </xsl:text>
					</span>
					<xsl:choose>
						<xsl:when test="local-name()='note'">
							<em>
								<xsl:apply-templates />
							</em>
						</xsl:when>
						<xsl:when test="(local-name()='app')">
							<xsl:apply-templates mode="bdp"/>
						</xsl:when>
					</xsl:choose>
					<xsl:if test="following::tei:rdg/text() | following::tei:app[not(@type)] | following::tei:note[@type='apparat']">
						<xsl:text> — </xsl:text>
					</xsl:if>
				</span>
				</xsl:for-each>
	</xsl:template>

	<!-- Template pour voir les notes qui n'ont pas d'xml:id : on ne demande pas à la XSL de numéroter les notes de a à z, mais d'afficher entre parenthèses l'xml:id -->
	<!-- <xsl:template name="apparat_bdp">
		<xsl:for-each select="//tei:app[not(@type)]">
				<span class="app" id="rdgBdp{@xml:id}">
					<xsl:variable name="numNoteApp">
						<xsl:value-of select="@xml:id"/>
					</xsl:variable>
					<span class="numApp" onclick="scrollToID('appelNote{$numNoteApp}')" style="cursor:pointer">
						<xsl:text>(</xsl:text>
						<xsl:value-of select="@xml:id"/>
						<xsl:text>) </xsl:text>
					</span>
					<xsl:choose>
						<xsl:when test="local-name()='note'">
							<em>
								<xsl:apply-templates />
							</em>
						</xsl:when>
						<xsl:when test="(local-name()='app')">
							<xsl:apply-templates mode="bdp"/>
						</xsl:when>
					</xsl:choose>
					<xsl:if test="following::tei:rdg/text() | following::tei:app[not(@type)] | following::tei:note[@type='apparat']">
						<xsl:text> — </xsl:text>
					</xsl:if>
				</span>
				</xsl:for-each>
	</xsl:template> -->

  <xsl:template match="tei:app" mode="bdp">
    <xsl:apply-templates select="tei:lem" mode="bdp"/>
    <xsl:apply-templates select="tei:rdg" mode="bdp"/>
  </xsl:template>

  <xsl:template match="tei:lem" mode="bdp">
  </xsl:template>

  <xsl:template match="tei:rdg" mode="bdp">
    <xsl:text> </xsl:text>
    <span class="texteRdg">
      <xsl:if test=".=''">
        <em>manquant </em>
      </xsl:if>
      <xsl:if test="preceding-sibling::tei:lem/tei:note">
        <xsl:apply-templates select="preceding-sibling::tei:lem/tei:note" mode="noteDansApp" />
        <xsl:text>, </xsl:text>
        <em>
          <xsl:value-of select="translate(preceding-sibling::tei:lem/@wit,'#','')" />
        </em>
        <xsl:text> ; </xsl:text>
      </xsl:if>
      <xsl:if test="preceding-sibling::tei:lem/tei:seg/tei:note[not(@type='scientifique')]">
        <xsl:apply-templates select="preceding-sibling::tei:lem/tei:seg/tei:note" mode="noteDansApp" />
        <xsl:text>, </xsl:text>
        <em>
          <xsl:value-of select="translate(preceding-sibling::tei:lem/@wit,'#','')" />
        </em>
        <xsl:text> ; </xsl:text>
      </xsl:if>
      <xsl:if test="preceding-sibling::tei:lem/tei:choice/tei:sic">
        <em>
          <xsl:text>Sic </xsl:text>
          <xsl:value-of select="translate(preceding-sibling::tei:lem/@wit,'#','')" />
          <xsl:text>, </xsl:text>
        </em>
      </xsl:if>
      <xsl:apply-templates/>
      <xsl:if test="preceding-sibling::tei:lem=''">
        <xsl:value-of select="tei:rdg"/>
        <em>
          <xsl:text> ajouté après ce mot</xsl:text>
        </em>
        <xsl:if test="tei:rdg/@wit">
          <xsl:text>, </xsl:text>
          <em>
            <xsl:value-of select="translate(tei:rdg/@wit,'#','')" />
          </em>
        </xsl:if>
      </xsl:if>
      <xsl:if test="@wit">
        <xsl:text> </xsl:text>
        <em>
          <xsl:value-of select="translate(translate(@wit,' ',''),'#','')" />
        </em>
      </xsl:if>
      <xsl:if test="tei:note">
        <xsl:text> ; </xsl:text>
        <em>
          <xsl:apply-templates select="tei:note" mode="noteDansApp"/>
        </em>
        <xsl:text>, </xsl:text>
        <em>
          <xsl:value-of select="translate(@wit, '#','')"/>
        </em>
      </xsl:if>
      <xsl:if test="preceding-sibling::tei:lem/tei:choice/tei:corr">
        <em>, comprendre </em>
        <xsl:value-of select="preceding-sibling::tei:lem/tei:choice/tei:corr" />
        <xsl:choose>
          <xsl:when test="preceding-sibling::tei:lem/tei:choice/tei:corr/@evidence='conjecture'">
          ?
          </xsl:when>
        </xsl:choose>
      </xsl:if>
      <xsl:if test="(position()!=last()) and (not(following-sibling::tei:note))">
        <xsl:text>, </xsl:text>
      </xsl:if>
    </span>
  </xsl:template>

	<!-- ###### witDetail et notes ###### -->
	<xsl:template name="bas_de_page">
		<div id="afficheBdp">
			<xsl:if test="//tei:witDetail">
					<div class="notesCommentaires">
						<h4 class="witdetail">witDetail</h4>
						<xsl:for-each select="//tei:witDetail">
							<xsl:variable name="numeroNote">
							<xsl:number count="//tei:witDetail" level="any" format="*1"/>
							</xsl:variable>
								<span class="notewitDetail" onclick="scrollToID('appelNote{$numeroNote}')" style="cursor:pointer">
									<xsl:value-of select="$numeroNote"/>
								<xsl:text>. </xsl:text>
								<xsl:apply-templates />
							</span>
							<xsl:text> | </xsl:text>
						</xsl:for-each>
					</div>
			</xsl:if>
			<xsl:if test="//tei:note[@type='sources']">
					<div class="notesSources">
						<h4 class="sources">Notes de sources</h4>
						<xsl:for-each select="//tei:note[@type='sources']">
							<xsl:variable name="numeroNote">
							<xsl:number count="//tei:note[@type='sources']" level="any" format="α"/>
							</xsl:variable>
								<span class="noteSources" onclick="scrollToID('appelNote{$numeroNote}')" style="cursor:pointer">
									<xsl:value-of select="$numeroNote"/>
								<xsl:text>. </xsl:text>
								<xsl:apply-templates />
							</span>
							<xsl:text> | </xsl:text>
						</xsl:for-each>
					</div>
			</xsl:if>
			<xsl:if test="//tei:note[@type='philologique']">
					<div class="notesPhilologiques">
						<h4 class="philologie">Notes philologiques</h4>
						<xsl:for-each select="//tei:note[@type='philologique']">
							<xsl:variable name="numeroNote">
							<xsl:number count="//tei:note[@type='philologique']" level="any" format="a'"/>
							</xsl:variable>
								<p class="notePhilo">
									<span class="notePhilo" onclick="scrollToID('appelNote{$numeroNote}')" style="cursor:pointer">
										<xsl:value-of select="$numeroNote"/>
									</span>
								<xsl:text>. </xsl:text>
								<xsl:apply-templates />
							</p>
						</xsl:for-each>
					</div>
			</xsl:if>
			<xsl:if test="//tei:note[@type='identification']">
					<div class="notesIdentification">
						<h4 class="identification">Notes d'identification</h4>
						<xsl:for-each select="//tei:note[@type='identification']">
							<xsl:variable name="numeroNote">
							<xsl:number count="//tei:note[@type='identification']" level="any" format="a'"/>
							</xsl:variable>
								<p class="noteIdent">
									<span class="noteIdent" onclick="scrollToID('appelNote{$numeroNote}')" style="cursor:pointer">
										<xsl:value-of select="$numeroNote"/>
									</span>
								<xsl:text>. </xsl:text>
								<xsl:apply-templates />
							</p>
						</xsl:for-each>
					</div>
			</xsl:if>
			<xsl:if test="//tei:note[@type='commentaire']">
					<div class="notesCommentaires">
						<h4 class="commentaire">Notes de commentaire</h4>
						<xsl:for-each select="//tei:note[@type='commentaire']">
							<xsl:variable name="numeroNote">
							<xsl:number count="//tei:note[@type='commentaire']" level="any" format="1"/>
							</xsl:variable>
								<p class="noteComm">
									<span class="noteComm" onclick="scrollToID('appelNote{$numeroNote}')" style="cursor:pointer">
										<xsl:value-of select="$numeroNote"/>
									</span>
								<xsl:text>. </xsl:text>
								<xsl:apply-templates />
							</p>
						</xsl:for-each>
					</div>
			</xsl:if>
		</div>
	</xsl:template>

	<!-- ###### données du front ###### -->
	<!-- ###### séparateur ###### -->
	<xsl:template match="tei:lb">
		<br/>
	</xsl:template>
	<!-- ###### enrichissements typo ###### -->
	<xsl:template match="tei:hi[@rend='italic']">
		<em>
			<xsl:apply-templates/>
		</em>
	</xsl:template>
	<xsl:template match="tei:hi[@rend='bold']">
		<strong>
			<xsl:apply-templates/>
		</strong>
	</xsl:template>
	<xsl:template match="tei:hi[@rend='sup']">
		<sup>
			<xsl:apply-templates/>
		</sup>
	</xsl:template>
	<xsl:template match="tei:hi[@rend='sup italic']">
		<sup>
			<em>
				<xsl:apply-templates/>
			</em>
		</sup>
	</xsl:template>
	<xsl:template match="tei:hi[@rend='small-caps']">
		<span class="small-caps">
			<xsl:apply-templates/>
		</span>
	</xsl:template>
	<!-- ###### tables ###### -->
	<xsl:template match="tei:table">
		<div class="table" anchor="@xml:id">
			<table>
				<xsl:if test="tei:head">
					<caption>
						<xsl:apply-templates select="tei:head"/>
					</caption>
				</xsl:if>
				<xsl:choose>
					<xsl:when test="tei:row[@role='label' and not(preceding::tei:row)]">
						<thead>
							<xsl:apply-templates select="tei:row[@role='label' and not(preceding::tei:row)]"/>
						</thead>
						<tbody>
							<xsl:apply-templates select="tei:row[not(@role='label' and not(preceding::tei:row))]"/>
						</tbody>
					</xsl:when>
					<xsl:otherwise>
						<xsl:apply-templates select="tei:row"/>
					</xsl:otherwise>
				</xsl:choose>
			</table>
			<xsl:apply-templates select="tei:note"/>
		</div>
	</xsl:template>
	<xsl:template match="tei:row">
		<tr>
			<xsl:apply-templates/>
		</tr>
	</xsl:template>
	<xsl:template match="tei:cell">
		<xsl:variable name="cellname">
			<xsl:choose>
				<xsl:when test="parent::tei:row[@role='label' and not(preceding::tei:row)]">th</xsl:when>
				<xsl:otherwise>td</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:element name="{$cellname}">
			<xsl:for-each select="@*">
				<xsl:choose>
					<xsl:when test="name(.)='cols'">
						<xsl:attribute name="colspan">
							<xsl:value-of select="."/>
						</xsl:attribute>
					</xsl:when>
					<xsl:when test="name(.)='rows'">
						<xsl:attribute name="rowspan">
							<xsl:value-of select="."/>
						</xsl:attribute>
					</xsl:when>
					<xsl:when test="name(.)='rendition'">
						<xsl:variable name="cellStyle" select="substring-after(.,'#')"/>
						<xsl:attribute name="style">
							<xsl:value-of select="$cellRendition//tei:rendition[@xml:id=$cellStyle]"/>
						</xsl:attribute>
					</xsl:when>
				</xsl:choose>
			</xsl:for-each>
			<xsl:apply-templates/>
		</xsl:element>
	</xsl:template>
	<!-- ###### listes ###### -->
	<xsl:template match="tei:list">
		<xsl:choose>
			<xsl:when test="@type='unordered'">
				<ul>
					<xsl:apply-templates/>
				</ul>
			</xsl:when>
			<xsl:otherwise>
				<ol>
					<xsl:apply-templates/>
				</ol>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="tei:item">
		<li>
			<xsl:apply-templates/>
		</li>
	</xsl:template>
	<!-- ###### images ###### -->
	<xsl:template match="tei:figure">
		<figure>
			<xsl:apply-templates/>
		</figure>
	</xsl:template>
	<xsl:template match="tei:head[parent::tei:figure]">
		<figcaption>
			<xsl:apply-templates/>
		</figcaption>
	</xsl:template>
	<xsl:template match="tei:graphic">
		<img class="fancybox">
			<xsl:attribute name="src">
				<xsl:value-of select="concat('../',@url)"/>
			</xsl:attribute>
			<xsl:attribute name="alt">
				<xsl:value-of select="following-sibling::tei:head"/>
			</xsl:attribute>
		</img>
	</xsl:template>
	<!-- ###### hyperliens ###### -->
	<xsl:template match="tei:ref">
		<a class="hyperlink">
			<xsl:attribute name="href">
				<xsl:value-of select="@target"/>
			</xsl:attribute>
			<xsl:apply-templates/>
		</a>
	</xsl:template>
	<!-- ###### index ###### -->


</xsl:stylesheet>
