<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:xhtml="http://www.w3.org/TR/xhtml/strict"
  xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
  xmlns:tei="http://www.tei-c.org/ns/1.0"
  xmlns="http://www.tei-c.org/ns/1.0"
  exclude-result-prefixes="tei"
>
  <xsl:output method="xml" encoding="UTF-8" indent="no"/>

<xsl:template match="@*|node()">
  <xsl:copy>
    <xsl:apply-templates select="@*|node()"/>
  </xsl:copy>
</xsl:template>

<!-- Les séquences à traiter en remplacement. Un nœud reg par chaîne -->
<!-- ORDER MATTERS!!!! -->
<xsl:variable name="regex">
  <root>
    <reg>
      <search>(\p{Zs})+</search>
      <replace><xsl:text>&#x20;</xsl:text></replace>
    </reg>
    <reg>
      <search>'</search>
      <replace>’</replace>
    </reg>
    <reg>
      <search>(\p{Zs}),</search>
      <replace>,</replace>
    </reg>
    <reg>
      <search>( |’|\()"\p{Zs}*</search>
      <replace>$1«&#160;</replace>
    </reg>
    <reg>
      <search>"( |\)|,|\.)</search>
      <replace>&#160;»$1</replace>
    </reg>
    <reg>
      <search>"((\p{L}| )+)"</search>
      <replace>«&#160;$1&#160;»</replace>
    </reg>
    <reg>
      <search>« </search>
      <replace>«&#160;</replace>
    </reg>
    <reg>
      <search> »</search>
      <replace>&#160;»</replace>
    </reg>
    <reg>
      <search>(\p{IsBasicLatin}\P{Zs})(;|:|\?|!)</search>
      <replace>$1&#160;$2</replace>
    </reg>
    <reg>
      <search> (;|:|\?|!)</search>
      <replace>&#160;$1</replace>
    </reg>
    <!-- Sans doute pas très robuste la suivante -->
    <reg>
      <search>(;|:|\?|!)(\p{L})</search>
      <replace>$1&#x20;$2</replace>
    </reg>
    <reg>
      <search>pp\.</search>
      <replace>p.</replace>
    </reg>
    <reg>
      <search>( p| t| f|vol|col|§)\. </search>
      <replace>$1.&#160;</replace>
    </reg>
    <reg>
      <search>(^p|^t|^f|^vol|^§|^col)\. </search>
      <replace>$1.&#160;</replace>
    </reg>
    <reg>
      <search>°</search>
      <replace>º</replace>
    </reg>
    <reg>
      <search>º\p{Zs}</search>
      <replace>º&#160;</replace>
    </reg>
    <reg>
      <search>[&#x28;] </search>
      <replace>&#x28;</replace>
    </reg>
    <reg>
      <search> [&#x29;]</search>
      <replace>&#x29;</replace>
    </reg>
    <reg>
      <search>\.\.\.</search>
      <replace>…</replace>
    </reg>
    <reg>
      <search>\p{Zs}…</search>
      <replace>…</replace>
    </reg>
    <reg>
      <search>Z\p{Zs}B</search>
      <replace>ZB</replace>
    </reg>
    <reg>
      <search>A\p{Zs}C</search>
      <replace>AC</replace>
    </reg>
    <reg>
      <search>EP\p{Zs}Pontieri</search>
      <replace>edd.</replace>
    </reg>
		<reg>
      <search>\p{Zs}EP</search>
      <replace>&#x20;ed.&#160;pr.</replace>
    </reg>
		<reg>
      <search>Z1</search>
      <replace>Z&#60;hi rend="sup"&#62;1&#60;/hi&#62;</replace>
    </reg>
		<reg>
      <search>Z2</search>
      <replace>Z&#60;hi rend="sup"&#62;2&#60;/hi&#62;</replace>
    </reg>
		<reg>
      <search>Zx</search>
      <replace>Z&#60;hi rend="sup"&#62;x&#60;/hi&#62;</replace>
    </reg>
		<reg>
      <search>C1</search>
      <replace>C&#60;hi rend="sup"&#62;1&#60;/hi&#62;</replace>
    </reg>
		<reg>
      <search>C2</search>
      <replace>C&#60;hi rend="sup"&#62;2&#60;/hi&#62;</replace>
    </reg>
		<reg>
      <search>Cx</search>
      <replace>C&#60;hi rend="sup"&#62;x&#60;/hi&#62;</replace>
    </reg>
		<reg>
      <search>B1</search>
      <replace>B&#60;hi rend="sup"&#62;1&#60;/hi&#62;</replace>
    </reg>
		<reg>
      <search>B2</search>
      <replace>B&#60;hi rend="sup"&#62;2&#60;/hi&#62;</replace>
    </reg>
		<reg>
      <search>Bx</search>
      <replace>B&#60;hi rend="sup"&#62;x&#60;/hi&#62;</replace>
    </reg>
		<reg>
      <search>add. ego</search>
      <replace>addidi</replace>
    </reg>
  </root>
</xsl:variable>

<!-- <xsl:template match="text()[ancestor::tei:note/@type='notice']"> -->
<xsl:template match="text()[ancestor::tei:note/@type='apparat_critique']">
  <xsl:call-template name="doRegex">
    <xsl:with-param name="currentText"><xsl:value-of select="."/></xsl:with-param>
    <xsl:with-param name="round" select="1"/>
  </xsl:call-template>
</xsl:template>

<xsl:template name="doRegex">
  <xsl:param name="currentText"/>
  <xsl:param name="round"/>
  <xsl:variable name="search"><xsl:value-of select="$regex/*:root/*:reg[position()=$round]/*:search"/></xsl:variable>
  <xsl:variable name="replace"><xsl:value-of select="$regex/*:root/*:reg[position()=$round]/*:replace"/></xsl:variable>
  <xsl:variable name="nextRound"><xsl:value-of select="$round+1"/></xsl:variable>
  
  <xsl:choose>
    <xsl:when test="$regex/*:root/*:reg[position()=$nextRound]/*:search">
      <xsl:call-template name="doRegex">
        <xsl:with-param name="currentText">
          <xsl:value-of select="replace($currentText,$search,$replace)"/>
        </xsl:with-param>
        <xsl:with-param name="round" select="$nextRound"/>
      </xsl:call-template>
    </xsl:when>
    <xsl:otherwise>
      <xsl:value-of select="replace($currentText,$search,$replace)"/>    
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

</xsl:stylesheet>